@@ -45,7 +45,7 @@ func TestMain(m *testing.M) {
 	cmd := exec.Command(goExe, "build")
 	err := cmd.Run()
 	if err != nil {
-		fmt.Printf("error building goawk: %v\n", err)
+		fmt.Fprintf(os.Stderr, "error building goawk: %v\n", err)
 		os.Exit(1)
 	}
 
@@ -684,6 +684,8 @@ func TestCSVDocExamples(t *testing.T) {
 				inTest = false
 			case "...":
 				truncated = true
+				runTest()
+				inTest = false
 			default:
 				output += line + "\n"
 			}
@@ -696,3 +698,40 @@ func TestCSVDocExamples(t *testing.T) {
 		t.Error("unexpectedly in test at end of file")
 	}
 }
+
+func TestMandelbrot(t *testing.T) {
+	stdout, stderr, err := runGoAWK([]string{"-v", "width=80", "-v", "height=25", "-f", "testdata/tt.x1_mandelbrot"}, "")
+	if err != nil {
+		t.Fatalf("expected no error, got %v (%q)", err, stderr)
+	}
+	expected := `
+................................................................................
+......................................................--+-----..................
+....................................................-----+*+-++-................
+.................................................--------+* *+-----.............
+..............................................--------+#     #%*-------.........
+.........................................------------++$       +-----------.....
+...................................---------*  # +*              # *+++++%+--...
+............................----------------++                       @   *----..
+.......................-+----------------+$                             %+----..
+..................-------*++%++**+++---++                                  #+--.
+...............----------+*         #*++*                                 %*---.
+.............-------+++++*              #                                 #----.
+....------+-------++**@  @                                               ------.
+....------+-------++**@  @                                               ------.
+.............-------+++++*              #                                 #----.
+...............----------+*         #*++*                                 %*---.
+..................-------*++%++**+++---++                                  #+--.
+.......................-+----------------+$                             %+----..
+............................----------------++                       @   *----..
+...................................---------*  # +*              # *+++++%+--...
+.........................................------------++$       +-----------.....
+..............................................--------+#     #%*-------.........
+.................................................--------+* *+-----.............
+....................................................-----+*+-++-................
+......................................................--+-----..................
+`[1:]
+	if stdout != expected {
+		t.Fatalf("expected:\n%s\ngot:\n%s", expected, stdout)
+	}
+}
